@@ -333,7 +333,11 @@ def get_dataset_id_from_model_id(model_name, model_id):
     """
     model_data = read_json_from_gcp_storage(
         file_path="captur-ml/models/model_bank.json")
-    model_versions = model_data.get("model_name")
+    model_name_data = model_data.get(model_name)
+    try:
+        model_versions = model_name_data.get("model_versions")
+    except AttributeError:
+        raise ModelNotFoundError(f"Model {model_name} not found.")
     dataset_id = None
     for version in model_versions:
         if version.get("model_id") == model_id:
